/*static const char sccsid[]="@(#)93/12/20 g.matas@ee.surrey.ac.uk 1.4 ConstSet.c";*/

#include "strGM.h"
#include "LL.h"
#include "PGLLstand.h"

/*------------------------------------------------------------------------*/
t_LLSet ConsLLSet(SetName,GeomStruct,format)
char * SetName; 
t_LL GeomStruct; 
char * format;
{
  t_LLSet Set;

  Set = (t_LLSet) malloc (sizeof(*Set));
  Set->id = DupStr(SetName);
  Set->format = DupStr(format);
  Set->GeomStruct = GeomStruct;
  Set->Attributes = ConsLL();
  Set->data = ConsLL();
  
  return Set;
}

void DestLLSet(Set)
t_LLSet Set;
{
 
  DestLL(Set->data);
  DestLL(Set->GeomStruct);
  DestLL(Set->Attributes);
  free(Set->id);
  free(Set->format);
  free(Set);
}
  
